# -*- coding: utf-8 -*-
from plone.app.upgrade.utils import loadMigrationProfile


def reload_gs_profile(context):
    loadMigrationProfile(
        context,
        "profile-plone.gallery:default",
    )



# -*- coding: utf-8 -*-
# from bs4 import BeautifulSoup
from plone import api
from plone.gallery.interfaces import IPloneGalleryLayer


try:
    from plone.base.utils import safe_text
except ModuleNotFoundError:
    from Products.CMFPlone.utils import safe_text

import logging


# import re


logger = logging.getLogger("plone.outputfilter.spam_filter")


class GalleryShortcode:
    """OUTPUTFILTER: Converts Gallery shortcodes into gallery markup.

    [gallery_shortcode]

    becomes:

    <div class="flexbin flexbin-margin">
        <a class="spotlight" href="http://localhost:8080/Plone/gallery-short/dsc04674.jpg/@@images/cf196084-6a72-48ee-af6a-1329a131bc69.jpeg" title="DSC04674.JPG" data-description="">
            <img loading="lazy" src="http://localhost:8080/Plone/gallery-short/dsc04674.jpg/@@images/68a16f1e-d967-42e8-b4e4-3c7a9f35ff68.jpeg" alt="DSC04674.JPG" title="DSC04674.JPG">
        </a>

        <a class="spotlight" href="http://localhost:8080/Plone/gallery-short/dsc04683.jpg/@@images/3ad1524b-cc31-4d50-a55b-24b796416d07.jpeg" title="DSC04683.JPG" data-description="">
            <img loading="lazy" src="http://localhost:8080/Plone/gallery-short/dsc04683.jpg/@@images/f2073429-acfa-465f-9819-c8e5d13a5a1c.jpeg" alt="DSC04683.JPG" title="DSC04683.JPG">
        </a>

        <a class="spotlight" href="http://localhost:8080/Plone/gallery-short/dsc04737.jpg/@@images/02288d38-6c51-414c-8d18-dbd5bf691627.jpeg" title="DSC04737.JPG" data-description="">
            <img loading="lazy" src="http://localhost:8080/Plone/gallery-short/dsc04737.jpg/@@images/5d597d6e-afd2-4a07-8413-45931f3411dc.jpeg" alt="DSC04737.JPG" title="DSC04737.JPG">
        </a>

        <a class="spotlight" href="http://localhost:8080/Plone/gallery-short/dsc04791.jpg/@@images/59ec67d5-c4f8-4e39-b6c3-be316a196f01.jpeg" title="DSC04791.JPG" data-description="">
            <img loading="lazy" src="http://localhost:8080/Plone/gallery-short/dsc04791.jpg/@@images/9aa3d108-120b-488b-a5c0-251cdddedf6e.jpeg" alt="DSC04791.JPG" title="DSC04791.JPG">
        </a>
    </div>

    """

    order = 1000

    def is_enabled(self):
        return True

    def __init__(self, context=None, request=None):
        self.current_status = None
        self.context = context
        self.request = request

    def __call__(self, data):
        if not IPloneGalleryLayer.providedBy(self.request):
            return data
        data = safe_text(data)
        view = api.content.get_view(
            name="gallery-list", context=self.context, request=self.request
        )
        gallery_markup = view()
        data = data.replace("[gallery_shortcode]", gallery_markup)
        return data



# -*- coding: utf-8 -*-
from plone.app.registry.browser.controlpanel import ControlPanelFormWrapper
from plone.app.registry.browser.controlpanel import RegistryEditForm
from plone.gallery import _
from plone.gallery.interfaces import IPloneGalleryLayer
from plone.restapi.controlpanels import RegistryConfigletPanel
from plone.z3cform import layout
from zope import schema
from zope.component import adapter
from zope.interface import Interface


class IPloneGalleryControlPanel(Interface):
    grid_image_scale = schema.Choice(
        title=_(
            "Grid Image Scale",
        ),
        description=_(
            "Image scale to use in the grid view.",
        ),
        vocabulary="plone.app.vocabularies.ImagesScales",
        default="preview",
        required=True,
    )
    zoom_image_scale = schema.Choice(
        title=_(
            "Zoom Image Scale",
        ),
        description=_(
            "Image scale to use when zoomed.",
        ),
        vocabulary="plone.app.vocabularies.ImagesScales",
        default="large",
        required=True,
    )


class PloneGalleryControlPanel(RegistryEditForm):
    schema = IPloneGalleryControlPanel
    schema_prefix = "plone.gallery"
    label = _("Plone Gallery Control Panel")


PloneGalleryControlPanelView = layout.wrap_form(
    PloneGalleryControlPanel, ControlPanelFormWrapper
)


@adapter(Interface, IPloneGalleryLayer)
class PloneGalleryControlPanelConfigletPanel(RegistryConfigletPanel):
    """Control Panel endpoint"""

    schema = IPloneGalleryControlPanel
    configlet_id = "plone-gallery-controlpanel"
    configlet_category_id = "Products"
    title = _("Plone Gallery Control Panel")
    group = ""
    schema_prefix = "plone.gallery"



# -*- coding: utf-8 -*-
"""Setup tests for this package."""
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.gallery.testing import PLONE_GALLERY_INTEGRATION_TESTING  # noqa: E501

import unittest


try:
    from Products.CMFPlone.utils import get_installer
except ImportError:
    get_installer = None


class TestSetup(unittest.TestCase):
    """Test that plone.gallery is properly installed."""

    layer = PLONE_GALLERY_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]

    def test_product_installed(self):
        """Test if plone.gallery is installed."""
        if get_installer:
            self.installer = get_installer(self.portal, self.layer["request"])
            self.assertTrue(self.installer.is_product_installed("plone.gallery"))
        else:
            self.installer = api.portal.get_tool("portal_quickinstaller")
            self.assertTrue(self.installer.isProductInstalled("plone.gallery"))

    def test_browserlayer(self):
        """Test that IPloneGalleryLayer is registered."""
        from plone.browserlayer import utils
        from plone.gallery.interfaces import IPloneGalleryLayer

        self.assertIn(IPloneGalleryLayer, utils.registered_layers())


class TestUninstall(unittest.TestCase):
    layer = PLONE_GALLERY_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        roles_before = api.user.get_roles(TEST_USER_ID)
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        if get_installer:
            self.installer = get_installer(self.portal, self.layer["request"])
            self.installer.uninstall_product("plone.gallery")
        else:
            self.installer = api.portal.get_tool("portal_quickinstaller")
            self.installer.uninstallProducts(["plone.gallery"])
        setRoles(self.portal, TEST_USER_ID, roles_before)

    def test_product_uninstalled(self):
        """Test if plone.gallery is cleanly uninstalled."""
        if get_installer:
            self.assertFalse(self.installer.is_product_installed("plone.gallery"))
        else:
            self.assertFalse(self.installer.isProductInstalled("plone.gallery"))

    def test_browserlayer_removed(self):
        """Test that IPloneGalleryLayer is removed."""
        from plone.browserlayer import utils
        from plone.gallery.interfaces import IPloneGalleryLayer

        self.assertNotIn(IPloneGalleryLayer, utils.registered_layers())



# -*- coding: utf-8 -*-

from . import logger
from .base import reload_gs_profile


# from plone import api


def upgrade(setup_tool=None):
    """ """
    logger.info(
        "Running upgrade (Python): Load profile to enable TinyMCE templates and resources"
    )
    reload_gs_profile(setup_tool)



# -*- coding: utf-8 -*-

# from plone.gallery import _
from .photo_gallery import BasePhotoGalleryMixin
from plone import api
from plone.app.contenttypes.interfaces import IImage
from Products.Five.browser import BrowserView
from zope.interface import implementer
from zope.interface import Interface


# from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile


class IGalleryList(Interface):
    """Marker Interface for IGalleryList"""


@implementer(IGalleryList)
class GalleryList(BrowserView, BasePhotoGalleryMixin):
    def __call__(self):
        return self.index()

    def album_images(self):
        images = []
        # if not hasattr(self.context, "related_photos"):
        #     return images
        related_photos = getattr(self.context, "related_photos", []) or []
        for item in related_photos:
            rel_obj = item.to_object
            if not IImage.providedBy(rel_obj):
                continue
            images.append(rel_obj)
        images.extend(
            api.content.find(
                context=self.context,
                portal_type="Image",
                sort_on="getObjPositionInParent",
            )
        )
        return images



# -*- coding: utf-8 -*-
from plone import api
from plone.app.contenttypes.browser.collection import CollectionView
from plone.app.contenttypes.browser.folder import FolderView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from zope.interface import implementer
from zope.interface import Interface


# from plone.gallery import _


class IPhotoGallery(Interface):
    """Marker Interface IPhotoGallery"""


class IPhotoGalleryCollection(Interface):
    """Marker Interface IPhotoGallery"""


class BasePhotoGalleryMixin:
    gallery_list_template = ViewPageTemplateFile("gallery_list.pt")

    def grid_image_scale(self, brain):
        grid_image_scale = api.portal.get_registry_record(
            "plone.gallery.grid_image_scale"
        )
        if hasattr(brain, "getObject"):
            image = brain.getObject()
        else:
            # already the object it self
            image = brain
        scale_util = api.content.get_view("images", image, self.request)
        return scale_util.scale("image", scale=grid_image_scale)

    def zoom_image_scale(self, brain):
        zoom_image_scale = api.portal.get_registry_record(
            "plone.gallery.zoom_image_scale"
        )
        if hasattr(brain, "getObject"):
            image = brain.getObject()
        else:
            # already the object it self
            image = brain
        scale_util = api.content.get_view("images", image, self.request)
        return scale_util.scale("image", scale=zoom_image_scale)


@implementer(IPhotoGallery)
class PhotoGallery(FolderView, BasePhotoGalleryMixin):
    def __call__(self):
        return self.index()


@implementer(IPhotoGalleryCollection)
class PhotoGalleryCollection(CollectionView, BasePhotoGalleryMixin):
    def __call__(self):
        return self.index()



# -*- coding: utf-8 -*-

# from plone import schema
from plone.app.vocabularies.catalog import CatalogSource
from plone.autoform import directives
from plone.autoform.interfaces import IFormFieldProvider
from plone.gallery import _
from plone.supermodel import model
from Products.CMFPlone.utils import safe_hasattr
from z3c import relationfield
from zope.component import adapter
from zope.interface import implementer
from zope.interface import Interface
from zope.interface import provider


# def get_base_path(path):
#     base_obj = api.content.get(path)
#     if not base_obj:
#         return
#     base_path = "/".join(base_obj.getPhysicalPath())
#     return base_path


def get_related_photos_base_path(context):
    return context.absolute_url_path()


class IRelatedPhotosMarker(Interface):
    pass


@provider(IFormFieldProvider)
class IRelatedPhotos(model.Schema):
    """ """

    directives.widget(
        "related_photos",
        pattern_options={
            "basePath": get_related_photos_base_path,
            "selectableTypes": ["Image"],
        },
    )
    related_photos = relationfield.schema.RelationList(
        title=_(
            "Related photos",
        ),
        description=_(
            'Related photos, rendered where you place the gallery_shortcode "[gallery_shortcode]".',
        ),
        value_type=relationfield.schema.RelationChoice(
            title="RelatedPhotos",
            source=CatalogSource(),
        ),
        required=False,
    )


@implementer(IRelatedPhotos)
@adapter(IRelatedPhotosMarker)
class RelatedPhotos(object):
    def __init__(self, context):
        self.context = context

    @property
    def related_photos(self):
        if safe_hasattr(self.context, "related_photos"):
            return self.context.related_photos or []
        return []

    @related_photos.setter
    def related_photos(self, value):
        self.context.related_photos = value



# -*- coding: utf-8 -*-
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.behavior.interfaces import IBehavior
from plone.gallery.behaviors.related_photos import IRelatedPhotosMarker
from plone.gallery.testing import PLONE_GALLERY_INTEGRATION_TESTING  # noqa
from zope.component import getUtility

import unittest


class RelatedPhotosIntegrationTest(unittest.TestCase):

    layer = PLONE_GALLERY_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])

    def test_behavior_related_photos(self):
        behavior = getUtility(IBehavior, "plone.gallery.related_photos")
        self.assertEqual(
            behavior.marker,
            IRelatedPhotosMarker,
        )



# -*- coding: utf-8 -*-
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.gallery.testing import PLONE_GALLERY_FUNCTIONAL_TESTING
from plone.gallery.testing import PLONE_GALLERY_INTEGRATION_TESTING
from plone.gallery.views.gallery_list import IGalleryList
from zope.component import getMultiAdapter

import unittest


class ViewsIntegrationTest(unittest.TestCase):

    layer = PLONE_GALLERY_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        api.content.create(self.portal, "Folder", "other-folder")
        api.content.create(self.portal, "Document", "front-page")

    def test_gallery_list_is_registered(self):
        view = getMultiAdapter(
            (self.portal["front-page"], self.portal.REQUEST), name="gallery-list"
        )
        self.assertTrue(IGalleryList.providedBy(view))


class ViewsFunctionalTest(unittest.TestCase):

    layer = PLONE_GALLERY_FUNCTIONAL_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
